@@ -533,7 +533,7 @@ class HealthLogUi:
 				return True
 
 
-	def showAllField(self,fields=[],not_none=[],total_drg=True,total_fd=False):
+	def showAllField(self,fields=[],not_none=[],total_drg=False,total_fd=False):
 		unit_registry=pint.UnitRegistry()
 		try:
 			useDateRange=Prompt.__init2__(None,func=FormBuilderMkText,ptext="use a date range?",helpText="yes or no",data="boolean")
@@ -600,11 +600,38 @@ class HealthLogUi:
 									dummy[i.DrugConsumed].DrugQtyConsumed=f.magnitude
 									dummy[i.DrugConsumed].DrugQtyConsumedUnitName=f.units
 								except Exception as e:
-									print(e,"processing will not include this value")
+									print(e,"processing will not include this")
+									print(f"{Back.grey_11}{i}{Style.reset}")
 							else:
 								dummy[i.DrugConsumed]=copy(i)
 						if total_fd:
-							pass
+							if 'total_fd' in dummy:
+								for x in fields:
+									includes=[
+											"CarboHydrateIntake",
+										    "ProtienIntake",
+										    "FiberIntake",
+										    "TotalFat",
+										    "SodiumIntake",
+										    "CholesterolIntake",
+											]
+									if x.name not in includes:
+										continue
+									if getattr(dummy['total_fd'],x.name) is None:
+										setattr(dummy['total_fd'],x.name,0)
+									else:
+										try:
+											uname=x.name+"UnitName"
+											old=unit_registry.Quantity(getattr(dummy['total_fd'],x.name),getattr(dummy['total_fd'],uname))
+											new=unit_registry.Quantity(getattr(i,x.name),getattr(i,uname))
+											f=old+new
+											setattr(dummy['total_fd'],x.name,f.magnitude)
+											setattr(dummy['total_fd'],uname,f.units)
+										except Exception as e:
+											print(e,"processing will not include this value")
+											print(f"{Back.grey_11}{i}{Style.reset}")
+							else:
+								dummy['total_fd']=copy(i)
 							
 					view=[]
 					for x in fields:
@@ -620,8 +647,9 @@ class HealthLogUi:
 				if total_drg or total_fd:
 					print(f"{Fore.orange_red_1}Broken into Totals{Style.reset}")
 					ct=len(dummy)
-					view=[]
+					
 					for num,i in enumerate(dummy):
+						view=[]
 						i=dummy[i]
 						for x in fields:
 							if getattr(i,str(x.name)) == None:
@@ -631,8 +659,8 @@ class HealthLogUi:
 								color=f"{Fore.sea_green_2}"
 								color_date=f"{Fore.green_3b}"
 							view.append(f'{color_date}{Style.bold}{str(x.name)}{Fore.deep_sky_blue_1}={color}{str(getattr(i,str(x.name)))}{Style.reset}')
-					msg=f"{Fore.light_green}{num}{Fore.light_yellow}/{num+1} of {Fore.light_red}{ct} ->{'|'.join(view)}"
-					print(msg)
+						msg=f"{Fore.light_green}{num}{Fore.light_yellow}/{num+1} of {Fore.light_red}{ct} ->{'|'.join(view)}"
+						print(msg)
 		except Exception as e:
 			print(e)
 
@@ -726,7 +754,7 @@ class HealthLogUi:
 			'lsdrug':{
 			'cmds':['ls drug','ls dg','list drug','lsdrug','lsdrg'],
 			'desc':'list drug data',
-			'exec':lambda self=self:self.showAllField(fields=['EntryBarcode','EntryName','DrugConsumed','DrugQtyConsumed','DrugQtyConsumedUnitName'],not_none=['DrugQtyConsumed',])
+			'exec':lambda self=self:self.showAllField(total_fd=False,total_drg=True,fields=['EntryBarcode','EntryName','DrugConsumed','DrugQtyConsumed','DrugQtyConsumedUnitName'],not_none=['DrugQtyConsumed',])
 			},
 			'xpt drug':{
 			'cmds':['xpt drug','xpt dg','export drug','xptdrug','xptdrg'],
@@ -787,7 +815,7 @@ class HealthLogUi:
 			'ls consumed':{
 				'cmds':['lsfd','ls fd','ls food','lfd','ls fuel','ls fl','lfl'],
 				'desc':'list food',
-				'exec':lambda self=self:self.showAllField(
+				'exec':lambda self=self:self.showAllField(total_fd=True,total_drg=False,
 					fields=["EntryBarcode",
 								"EntryName",
 								"CarboHydrateIntake",
